# Agile toolkit

[![PyPI version](https://badge.fury.io/py/agile-toolkit.svg)](https://badge.fury.io/py/agile-toolkit)
[![Python versions](https://img.shields.io/pypi/pyversions/agile-toolkit.svg)](https://pypi.org/project/agile-toolkit)
[![CircleCI](https://circleci.com/gh/quantmind/agile-toolkit.svg?style=svg)](https://circleci.com/gh/quantmind/agile-toolkit)
[![codecov](https://codecov.io/gh/quantmind/agile-toolkit/branch/master/graph/badge.svg)](https://codecov.io/gh/quantmind/agile-toolkit)
